@@ -164,6 +164,65 @@ class CroniterTest(base.TestCase):
         self.assertEqual(n4.month, 1)
         self.assertEqual(n4.year, 2011)
 
+    def testLastDayOfMonth(self):
+        base = datetime(2015, 9, 4)
+        itr = croniter('0 0 l * *', base)
+        n1 = itr.get_next(datetime)
+        self.assertEqual(n1.month, 9)
+        self.assertEqual(n1.day, 30)
+        n2 = itr.get_next(datetime)
+        self.assertEqual(n2.month, 10)
+        self.assertEqual(n2.day, 31)
+        n3 = itr.get_next(datetime)
+        self.assertEqual(n3.month, 11)
+        self.assertEqual(n3.day, 30)
+        n4 = itr.get_next(datetime)
+        self.assertEqual(n4.month, 12)
+        self.assertEqual(n4.day, 31)
+
+    def testPrevLastDayOfMonth(self):
+        base = datetime(2009, 12, 31, hour=20)
+        itr = croniter('0 0 l * *', base)
+        n1 = itr.get_prev(datetime)
+        self.assertEqual(n1.month, 12)
+        self.assertEqual(n1.day, 31)
+
+        base = datetime(2009, 12, 31)
+        itr = croniter('0 0 l * *', base)
+        n1 = itr.get_prev(datetime)
+        self.assertEqual(n1.month, 11)
+        self.assertEqual(n1.day, 30)
+
+        base = datetime(2010, 1, 5)
+        itr = croniter('0 0 l * *', base)
+        n1 = itr.get_prev(datetime)
+        self.assertEqual(n1.month, 12)
+        self.assertEqual(n1.day, 31)
+        n1 = itr.get_prev(datetime)
+        self.assertEqual(n1.month, 11)
+        self.assertEqual(n1.day, 30)
+        n1 = itr.get_prev(datetime)
+        self.assertEqual(n1.month, 10)
+        self.assertEqual(n1.day, 31)
+        n1 = itr.get_prev(datetime)
+        self.assertEqual(n1.month, 9)
+        self.assertEqual(n1.day, 30)
+
+        base = datetime(2010, 1, 31, minute=2)
+        itr = croniter('* * l * *', base)
+        n1 = itr.get_prev(datetime)
+        self.assertEqual(n1.month, 1)
+        self.assertEqual(n1.day, 31)
+        n1 = itr.get_prev(datetime)
+        self.assertEqual(n1.month, 1)
+        self.assertEqual(n1.day, 31)
+        n1 = itr.get_prev(datetime)
+        self.assertEqual(n1.month, 12)
+        self.assertEqual(n1.day, 31)
+        n1 = itr.get_prev(datetime)
+        self.assertEqual(n1.month, 12)
+        self.assertEqual(n1.day, 31)
+
     def testError(self):
         itr = croniter('* * * * *')
         self.assertRaises(TypeError, itr.get_next, str)
@@ -414,7 +473,7 @@ class CroniterTest(base.TestCase):
         for expected_date, expected_offset in expected_schedule:
             d = callback()
             self.assertEqual(expected_date, d.replace(tzinfo=None))
-            self.assertEqual(expected_offset, d.utcoffset().total_seconds())
+            self.assertEqual(expected_offset, croniter._timedelta_to_seconds(d.utcoffset()))
 
     def testTimezoneWinterTime(self):
         tz = pytz.timezone('Europe/Athens')
